@@ -18,8 +18,7 @@ LOG.addHandler(ch)
 LOG.setLevel(logging.DEBUG)
 
 
-def main(argv):
-    src_instance_id = argv[0]
+def main(src_instance_id):
     NetworkHealthChecker(src_instance_id).check_network_connectivity()
 
 
@@ -113,6 +112,3 @@ class NetworkHealthChecker(object):
         except Exception as e:
             LOG.error('Public network connectivity check failed: %s' % e)
             raise
-
-if __name__ == "__main__":
-    main(sys.argv[1:])
